import React from 'react';
import { Route, Redirect } from 'react-router-dom';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import { inactiveToken, activeToken } from './../../actions/auth/tokenCheckout'
import decode from 'jwt-decode';

import * as routes from './../../constants/routes';
import storageKey from './../../utils/storageKey';

const protectedRoute = ({ component: Component, activeToken, inactiveToken, access, ...rest }) => (
    <Route
        {...rest}
        render={props => {
            try {
                const user = decode(localStorage.getItem(storageKey));
                activeToken(user.role);
                {/* if (user.exp < Date.now()*1000) {
                    throw new Error('Date expired');
                } */}

                if (access === 'admin-only' && !user.role) {
                    throw new Error('Permission Denied')
                }

                return <Component {...props} />
            }
            catch ({ message }) {
                if (message === 'Permission Denied') {
                    return <div>Permission denied</div>
                }

                inactiveToken();

                if (access === 'public') {
                    return <Component {...props} />
                }

                return <Redirect to={routes.SIGN_IN} />
            }
        }}
    />
)

const mapDispatchToProps = dispatch => bindActionCreators({
    activeToken,
    inactiveToken
}, dispatch);

export default connect(null, mapDispatchToProps)(protectedRoute);