import React, { PureComponent } from 'react';
import { Link, withRouter, Redirect } from "react-router-dom";
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import axios from 'axios';

import storageKey from './../../utils/storageKey';
import { signInStateZeroing } from './../../actions/auth/signIn';
import { LOG_OUT_URL } from './../../constants/auth';

import * as routes from '../../constants/routes';

//pure component + make storage check an action -> connect router
class Header extends PureComponent {
    handleLogOut = () => {
        console.log(this.props)
        const { history, zeroState } = this.props;

        axios.get(LOG_OUT_URL, {})
            .then(() => {
                console.log('request was succesfull')
                localStorage.removeItem(storageKey);
                zeroState();
                history.push('/sign-in');
            })
            .catch(e => alert('Sorry, something bad happened, try log out later \n' + e.message));
    }

    render() {
        const { role } = this.props;

        return (
            <nav className="navbar navbar-expand-lg navbar-dark bg-dark p-3">
                <Link to={routes.LANDING} className="navbar-brand" href="#">Test.io</Link>
                <button className="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
                    <span className="navbar-toggler-icon" />
                </button>

                <div className="collapse navbar-collapse" id="navbarSupportedContent">
                    <ul className="navbar-nav mr-auto">
                        <li className="nav-item active">
                            <Link onClick={this.handleClick} className="nav-link" to={routes.HOME}>Home <span className="sr-only">(current)</span></Link>
                        </li>
                        <li className="nav-item">
                            <Link onClick={this.handleClick} className="nav-link" to={routes.PROFILE}>Profile</Link>
                        </li>
                        <li className="nav-item">
                            <Link onClick={this.handleClick} className="nav-link" to={routes.TESTS}>Tests</Link>
                        </li>
                        <li className="nav-item">
                            <Link onClick={this.handleClick} className="nav-link" to={routes.CATEGORIES}>Catigories</Link>
                        </li>
                        {/* TODO: admin-only ! */}
                        {
                            role
                                ?
                                <li className="nav-item dropdown">
                                    {/* eslint-disable-next-line */}
                                    <a className="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                        Dropdown
                                </a>
                                    <div className="dropdown-menu" aria-labelledby="navbarDropdown">
                                        <Link to={routes.CREATE_TEST} className="nav-link text-secondary">Create Test</Link>
                                        <Link to={routes.CREATE_CATEGORY} className="nav-link text-secondary">Create Category</Link>

                                        <div className="dropdown-divider"></div>
                                        {/* eslint-disable-next-line */}
                                        <a className="nav-link text-secondary" href="#">Something else here</a>
                                    </div>
                                </li>
                                :
                                null
                        }
                    </ul>
                    <form className="form-inline my-lg-0">
                        <input className="form-control mr-sm-2" type="search" placeholder="Search" aria-label="Search" />
                        <button className="btn btn-outline-success my-2 my-sm-0 mr-2" type="submit">Search</button>
                    </form>
                    <div className="controls">
                        {
                            role !== null
                                ?
                                <button onClick={this.handleLogOut} className="btn btn-outline-primary">Log Out</button>
                                :
                                <React.Fragment>
                                    <Link to={routes.SIGN_IN}>
                                        <button className="btn btn-outline-primary">Sign In</button>
                                    </Link>
                                    <Link to={routes.SIGN_UP}>
                                        <button className="btn btn-outline-primary mx-2">Sign Up</button>
                                    </Link>
                                </React.Fragment>
                        }
                    </div>
                </div>
            </nav>
        )
    }
}

const mapStateToProps = state => ({
    role: state.tokenCheckout.role,
});
const mapDispatchToProps = dispatch => bindActionCreators({
    zeroState: signInStateZeroing
}, dispatch)

export default withRouter(connect(mapStateToProps, mapDispatchToProps)(Header));